"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const experimental_utils_1 = require("@typescript-eslint/experimental-utils");
const util = __importStar(require("../utils"));
function isBuiltinElement(node) {
    return node.name.type === "JSXIdentifier" && /^[a-z]+$/.test(node.name.name);
}
function getEmptyStyleProp(node) {
    return node.attributes.find((x) => {
        var _a;
        return x.type === experimental_utils_1.AST_NODE_TYPES.JSXAttribute &&
            typeof x.name.name === "string" &&
            x.name.name === "style" &&
            ((_a = x.value) === null || _a === void 0 ? void 0 : _a.type) === experimental_utils_1.AST_NODE_TYPES.JSXExpressionContainer &&
            x.value.expression.type === experimental_utils_1.AST_NODE_TYPES.ObjectExpression &&
            x.value.expression.properties.length === 0;
    });
}
function isEmptyStringExpr(node) {
    return ((node.type === experimental_utils_1.AST_NODE_TYPES.Literal && node.value === "") ||
        (node.type === experimental_utils_1.AST_NODE_TYPES.TemplateLiteral &&
            node.expressions.length === 0 &&
            node.quasis.length === 1 &&
            node.quasis[0].value.cooked === ""));
}
function getEmptyClassNameProp(node) {
    return node.attributes.find((x) => {
        var _a, _b;
        return x.type === experimental_utils_1.AST_NODE_TYPES.JSXAttribute &&
            typeof x.name.name === "string" &&
            x.name.name === "className" &&
            ((((_a = x.value) === null || _a === void 0 ? void 0 : _a.type) === experimental_utils_1.AST_NODE_TYPES.Literal && x.value.value === "") ||
                (((_b = x.value) === null || _b === void 0 ? void 0 : _b.type) === experimental_utils_1.AST_NODE_TYPES.JSXExpressionContainer &&
                    isEmptyStringExpr(x.value.expression)));
    });
}
function checkNode(node, context) {
    const emptyStyleProp = getEmptyStyleProp(node);
    if (emptyStyleProp != null) {
        context.report({
            node,
            messageId: "EmptyStyleProp",
            fix: (fixer) => fixer.remove(emptyStyleProp),
        });
    }
    const emptyClassNameProp = getEmptyClassNameProp(node);
    if (emptyClassNameProp != null) {
        context.report({
            node,
            messageId: "EmptyClassNameProp",
            fix: (fixer) => fixer.remove(emptyClassNameProp),
        });
    }
}
exports.default = util.createRule({
    name: "jsx-no-useless-style-classname",
    meta: {
        type: "suggestion",
        fixable: "code",
        docs: {
            description: "Disallow unnecessary style and className props.",
            category: "Best Practices",
            recommended: "error",
        },
        messages: {
            EmptyStyleProp: "An empty style prop is a no-op.",
            EmptyClassNameProp: "An empty className is a no-op.",
        },
        schema: [],
    },
    defaultOptions: [],
    create(context) {
        return {
            JSXOpeningElement(node) {
                if (isBuiltinElement(node)) {
                    checkNode(node, context);
                }
            },
        };
    },
});
//# sourceMappingURL=jsx-no-useless-style-classname.js.map