"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const experimental_utils_1 = require("@typescript-eslint/experimental-utils");
const lodash_1 = require("lodash");
const util = __importStar(require("../utils"));
function getUnusedFields(node, context) {
    const parserServices = util.getParserServices(context);
    const typeChecker = parserServices.program.getTypeChecker();
    const objectType = typeChecker.getTypeAtLocation(parserServices.esTreeNodeToTSNodeMap.get(node));
    const typeProperties = objectType.getProperties().map((x) => x.name);
    const paramProperties = [];
    for (const prop of node.properties) {
        if (prop.type === experimental_utils_1.AST_NODE_TYPES.Property &&
            prop.key.type === experimental_utils_1.AST_NODE_TYPES.Identifier) {
            paramProperties.push(prop.key.name);
        }
    }
    return lodash_1.difference(typeProperties, paramProperties);
}
function checkNode(node, context) {
    if (node.params.length === 1 &&
        node.params[0].type === experimental_utils_1.AST_NODE_TYPES.ObjectPattern &&
        node.params[0].properties.every((param) => param.type !== experimental_utils_1.AST_NODE_TYPES.RestElement)) {
        const unusedFields = getUnusedFields(node.params[0], context);
        if (unusedFields.length > 0)
            context.report({
                node: node.params[0],
                data: {
                    unusedFields,
                },
                messageId: "PartialArgDestructure",
            });
    }
}
exports.default = util.createRule({
    name: "no-partial-arg-destructure",
    meta: {
        type: "suggestion",
        docs: {
            description: "Usused params can hide dead code.",
            category: "Best Practices",
            recommended: "error",
        },
        messages: {
            PartialArgDestructure: "Remove the unused fields in param type: '{{ unusedFields }}'.",
        },
        schema: [],
    },
    defaultOptions: [],
    create(context) {
        return {
            FunctionDeclaration(node) {
                checkNode(node, context);
            },
            VariableDeclaration(node) {
                var _a;
                for (const decl of node.declarations) {
                    if (((_a = decl.init) === null || _a === void 0 ? void 0 : _a.type) === experimental_utils_1.AST_NODE_TYPES.ArrowFunctionExpression) {
                        checkNode(decl.init, context);
                    }
                }
            },
        };
    },
});
//# sourceMappingURL=no-partial-arg-destructure.js.map