"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_no_useless_style_classname_1 = __importDefault(require("../../rules/jsx-no-useless-style-classname"));
const RuleTester_1 = require("../RuleTester");
const rootDir = RuleTester_1.getFixturesRootDir();
const ruleTester = new RuleTester_1.RuleTester({
    parser: "@typescript-eslint/parser",
    parserOptions: {
        ecmaVersion: 2018,
        tsconfigRootDir: rootDir,
        sourceType: "module",
        ecmaFeatures: { jsx: true },
    },
});
ruleTester.run("jsx-no-useless-style-classname", jsx_no_useless_style_classname_1.default, {
    valid: [
        {
            code: "<Section style={{}} />",
        },
        {
            code: "<Section className={''} />",
        },
        {
            code: `<Section className="" />`,
        },
        {
            code: "<Section className={``} />",
        },
        {
            code: "<div className={`foo`} />",
        },
        {
            code: "<div className={'bar'} />",
        },
        {
            code: `<div className="buzz" />`,
        },
        {
            code: `<div style={{height: 100}} />`,
        },
    ],
    invalid: [
        {
            code: `<section foo="bar" style={{}} buzz={true} />`,
            output: `<section foo="bar"  buzz={true} />`,
            errors: [{ messageId: "EmptyStyleProp" }],
        },
        {
            code: `<section foo="bar" className={''} buzz={true} />`,
            output: `<section foo="bar"  buzz={true} />`,
            errors: [{ messageId: "EmptyClassNameProp" }],
        },
        {
            code: `<section className="" />`,
            output: `<section  />`,
            errors: [{ messageId: "EmptyClassNameProp" }],
        },
        {
            code: "<section className={``} />",
            output: `<section  />`,
            errors: [{ messageId: "EmptyClassNameProp" }],
        },
        {
            code: `<section style={{}} className="" />`,
            output: `<section   />`,
            errors: [
                { messageId: "EmptyStyleProp" },
                { messageId: "EmptyClassNameProp" },
            ],
        },
    ],
});
//# sourceMappingURL=jsx-no-useless-style-classname.test.js.map