"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const no_partial_arg_destructure_1 = __importDefault(require("../../rules/no-partial-arg-destructure"));
const RuleTester_1 = require("../RuleTester");
const rootDir = RuleTester_1.getFixturesRootDir();
const ruleTester = new RuleTester_1.RuleTester({
    parser: "@typescript-eslint/parser",
    parserOptions: {
        ecmaVersion: 2018,
        tsconfigRootDir: rootDir,
        project: "./tsconfig.json",
    },
});
ruleTester.run("no-partial-arg-destructure", no_partial_arg_destructure_1.default, {
    valid: [
        {
            code: `
type Params = {
  buzz: string
  bar: number
}
function Foo({buzz, bar}: Params) {}`,
        },
        {
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     function Foo({buzz, ...rest}: Params) {}`,
        },
        {
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     const Foo = ({buzz, ...rest}: Params) => {}`,
        },
        {
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     const Foo = ({buzz}: Pick<Params, "buzz">) => {}`,
        },
        {
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     function Foo(props: Params) {}`,
        },
        {
            code: `
     function Foo({}: {}) {}`,
        },
        {
            code: `
     function Foo({}: any) {}`,
        },
        {
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     const Foo = (props: Params) => {}`,
        },
    ],
    invalid: [
        {
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     function Foo({buzz}: Params) {}`,
            errors: [
                {
                    messageId: "PartialArgDestructure",
                    data: { unusedFields: ["bar"] },
                },
            ],
        },
        {
            // shouldn't matter if we use an interface or type
            code: `
     interface Params {
       buzz: string
       bar: number
     }
     function Foo({buzz}: Params) {}`,
            errors: [
                {
                    messageId: "PartialArgDestructure",
                    data: { unusedFields: ["bar"] },
                },
            ],
        },
        {
            // should also check arrow functions
            code: `
     type Params = {
       buzz: string
       bar: number
     }
     const Foo = ({buzz}: Params) => {}`,
            errors: [
                {
                    messageId: "PartialArgDestructure",
                    data: { unusedFields: ["bar"] },
                },
            ],
        },
    ],
});
//# sourceMappingURL=no-partial-arg-destructure.test.js.map